require 'uu/os/form/input'

module UU
  module OS
    module Form

      # File input component.
      class File < UU::OS::Form::Input

        # URI of bucket where to store files.
        attr_accessor :bucket_uri

        # Which storage service to use for binary data. By default, UDS service is used.
        # See {StorageType} for available options.
        #
        # Note that using {StorageType::UU_BINARYSTORE} has additional requirements
        # for VUC controller - see {https://plus4u.net/ues/sesm?&SessFree=ues%3AUNI-BT%3AUES.DOC%2FUU.BINARYSTORE%2FHOWTO-USE documentation} for more information.
        attr_reader :storage_type

        def bucket_uri
          attributes[:bucketUri]
        end

        def bucket_uri=(value)
          attributes[:bucketUri] = value
        end

        def storage_type
          attributes[:storageType]
        end

        class StorageType
          UU_UDS = 'UU_UDS'
          UU_BINARYSTORE = 'UU_BINARYSTORE'
        end

      end

    end
  end
end
