require 'uu/os/gvc/component'

module UU
  module OS
    module GVC

      # Component for displaying text. Use this component when it's necessary to
      # dynamically change text. Don't use this component for static texts that
      # don't change during the life-time of VUC (put such text directly into VUC view).
      class Text < UU::OS::GVC::Component

        # Text content of the component. The value is truncated to 2000 characters.
        # Newlines and other whitespaces are preserved when text is displayed to user.
        attr_accessor :text

        # The style for the component. The value can be semicolon separated String
        # containing style rules or a Hash. Allowed styles:
        #
        # * color, background-color - the color of the text / background as a hexa value, e.g. '#123456'.
        # * font-family, font-size, font-style, font-weight - font styling (see CSS for possible values)
        # * text-decoration - underline / strike-through decorations (see CSS for possible values)
        #
        # @return The style for the component. Due to backward compatibility,
        #         the return value is the same as the one used for setting the value.
        # @example
        #   text.style = { :color => '#123456' }
        #   a = text.style                       # returns { :color => '#123456' }
        #
        #   text.style = 'font-style: italic; font-weight: bold; font-size: 15px;'
        #   b = text.style                       # returns 'font-style: italic; font-weight: bold; font-size: 15px;'
        attr_accessor :style
        
        # Minimal width of the component.
        attr_reader :min_width
        
        # Maximal width of the component.
        attr_reader :max_width

        def text
          attributes[:text]
        end

        def text=(text)
          attributes[:text] = text.length > 2000 ? text[0, 2000] : text
        end

        def style
          attributes[:style]
        end

        def style=(style)
          attributes[:style] = style
        end
        
        def min_width
          attributes[:minWidth]
        end
        
        def max_width
          attributes[:maxWidth]
        end

      end
    end
  end
end
